@@ -1,16 +1,16 @@
 import celescope.tools.utils as utils
-from celescope.tools.star import Star, get_opts_star
+from celescope.tools.star_mixin import StarMixin, get_opts_star_mixin
+from celescope.tools.step import Step
 
 
-class StarFusion(Star):
+class StarFusion(Step, StarMixin):
     def __init__(self, args, step_name):
-        Star.__init__(self, args, step_name)
-        self.STAR_index = args.fusion_genomeDir
+        args.genomeDir = args.fusion_genomeDir
+        Step.__init__(self, args, step_name)
+        StarMixin.__init__(self, args)
 
     def run(self):
-        self.STAR()
-        self.sort_bam()
-        self.index_bam()
+        self.run_star()
         self.clean_up()
 
 
@@ -22,7 +22,7 @@ def star_fusion(args):
 
 
 def get_opts_star_fusion(parser, sub_program):
-    get_opts_star(parser, sub_program)
+    get_opts_star_mixin(parser, sub_program)
     # will cause `conflicting option string: --genomeDir`
     # parser.add_argument('--genomeDir', help=argparse.SUPPRESS)
     parser.add_argument('--fusion_genomeDir', help='fusion gene STAR index genome directory', required=True)
