@@ -1,8 +1,9 @@
-import unittest
 import os
-import pandas as pd
-from celescope.hla.mapping_hla import split_bam, hla_typing, summary, read_index
-from celescope.tools.utils import *
+import unittest
+
+from celescope.hla.mapping_hla import (hla_typing, read_index, split_bam,
+                                       summary)
+from celescope.tools.utils import read_barcode_file
 
 
 class testHLA(unittest.TestCase):
