@@ -1,5 +1,4 @@
-import os
-from celescope.tools.utils import *
+from celescope.tools.utils import STAR_util, add_log
 
 
 @add_log
