@@ -3,16 +3,15 @@
 # Copyright (c) 2015 10X Genomics, Inc. All rights reserved.
 #
 
-import array
+import sys
+
 import numpy as np
 import scipy.stats as sp_stats
-import sys
+
 # import cellranger.constants as cr_constants
 # import tenkit.constants as tk_constants
 # import tenkit.seq as tk_seq
 # import tenkit.stats as tk_stats
-import collections
-import sklearn.mixture as sk_mix
 
 # def to_col_vec(a):
 #     """ Convert a 1-d array to a column vector """
