@@ -1,12 +1,12 @@
-import os
-import glob
 import argparse
+import glob
 import itertools
+import os
 from collections import defaultdict
 
 import celescope
 from celescope.tools.utils import find_assay_init, find_step_module
-
+from celescope.celescope import ArgFormatter
 
 TOOLS_DIR = os.path.dirname(celescope.tools.__file__)
 
@@ -22,6 +22,12 @@ class Multi():
         self.col4_default = None
         self.last_step = ''
         self.args = None
+        self.steps_not_run = ['mkref']
+        
+        # remove
+        for step in self.steps_not_run:
+            if step in self.__STEPS__:
+                self.__STEPS__.remove(step)
 
         # parse_args
         self.common_args()
@@ -41,7 +47,7 @@ class Multi():
     def common_args(self):
         readme = f'{self.__ASSAY__} multi-samples'
         parser = argparse.ArgumentParser(readme, 
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            formatter_class=ArgFormatter,
             conflict_handler='resolve')
         parser.add_argument('--mod', help='mod, sjm or shell', choices=['sjm', 'shell'], default='sjm')
         parser.add_argument(
@@ -78,10 +84,10 @@ class Multi():
                 line = line.strip()
                 if not line or line.startswith('#'):
                     continue
-                tmp = line.split()
-                library_id, library_path, sample_name = tmp[:3]
-                if len(tmp) == 4:
-                    col4 = tmp[3]
+                line_split = line.split()
+                library_id, library_path, sample_name = line_split[:3]
+                if len(line_split) == 4:
+                    col4 = line_split[3]
                 else:
                     col4 = default_val
                 fq1, fq2 = get_fq(library_id, library_path)
@@ -180,7 +186,7 @@ job_end
             f'--thread {self.args.thread} '
         )
         cmd_line = step_prefix
-        if self.__CONDA__ == "celescope_RD":
+        if self.args.debug or self.__CONDA__ == "celescope_RD":
             cmd_line += " --debug "
         for arg in args_dict:
             if args_dict[arg] is False:
@@ -286,6 +292,8 @@ job_end
         for sample in self.fq_dict:
             self.last_step = ''
             for step in self.steps_run:
+                if step in self.steps_not_run:
+                    continue
                 try:
                     method_to_call = getattr(self, step)
                 except AttributeError as attr_not_exist:
