@@ -1,11 +1,12 @@
 import os
+
 import pandas as pd
 
-from celescope.__init__ import __VERSION__, ASSAY_DICT
 import celescope.tools.utils as utils
+from celescope.__init__ import __VERSION__, ASSAY_DICT
 from celescope.tools.__init__ import __PATTERN_DICT__
-from .Chemistry import Chemistry
-from celescope.tools.Step import Step, s_common
+from celescope.tools.barcode import Chemistry
+from celescope.tools.step import Step, s_common
 
 
 @utils.add_log
@@ -52,6 +53,6 @@ def get_opts_sample(parser, sub_program):
     if sub_program:
         parser = s_common(parser)
         parser.add_argument('--fq1', help='read1 fq file')
-    parser.add_argument('--chemistry', choices=__PATTERN_DICT__.keys(), help='chemistry version', default='auto')
+    parser.add_argument('--chemistry', choices=list(__PATTERN_DICT__.keys()), help='chemistry version', default='auto')
     return parser
     
