@@ -1,11 +1,15 @@
 import unittest
 from collections import namedtuple
-from celescope.tools.step import Step
-from .consensus import dumb_consensus, get_read_length
+
+from celescope.tools.consensus import dumb_consensus, get_read_length
 from celescope.tools.count import Count
+from celescope.tools.step import Step
 
 
 class Tests(unittest.TestCase):
+    """
+    Run this test under a temp folder as it will generate some files.
+    """
     def setUp(self):
         pass
 
@@ -52,8 +56,8 @@ class Tests(unittest.TestCase):
         sorted_dic = sorted(dic.items(), key=lambda x:x[1])
         assert sorted_dic == [('ccccc1', 20), ('apple2', 32), ('bears3', 115), ('ccccc2', 199)]
         assert n_corrected_umi == 3
-        assert n_corrected_read == 2 + 5 + 10
+        assert n_corrected_read == 2 + 5 + 10  
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
